@@ -67,6 +67,27 @@ func newTestDirWithFiles(t *testing.T) string {
 	return directoryPath
 }
 
+// chdirWithCleanup changes the current working directory to the named directory,
+// and then restore the original working directory at the end of the test.
+//
+// TODO: Once we are on 1.24 we can replace this with t.Chdir()
+func chdirWithCleanup(t *testing.T, dir string) {
+	olddir, err := os.Getwd()
+	if err != nil {
+		t.Fatalf("chdir: %v", err)
+	}
+	if err := os.Chdir(dir); err != nil {
+		t.Fatalf("chdir %s: %v", dir, err)
+	}
+
+	t.Cleanup(func() {
+		if err := os.Chdir(olddir); err != nil {
+			t.Errorf("chdir to original working directory %s: %v", olddir, err)
+			os.Exit(1)
+		}
+	})
+}
+
 func writePipeChar(buf *bytes.Buffer, index int) {
 	if index == 0 {
 		return
@@ -306,10 +327,80 @@ func TestExecute_NotOverwrite(t *testing.T) {
 		expectRepresentation(t, directoryPath, `
 .
 ├─output.md "**file content A**"
-	`)
+		`)
 	})
 }
 
+func TestExecute_DuplicateFiles(t *testing.T) {
+	directoryPath := newTestDir(t)
+	defer os.RemoveAll(directoryPath)
+
+	chdirWithCleanup(t, directoryPath)
+
+	inputFolderA := filepath.Join(directoryPath, "input", "a")
+	inputFolderB := filepath.Join(directoryPath, "input", "b")
+	inputFolderC := filepath.Join(directoryPath, "input", "nested", "c")
+
+	err := os.MkdirAll(inputFolderA, os.ModePerm)
+	if err != nil {
+		t.Fatal(err)
+	}
+	err = os.MkdirAll(inputFolderB, os.ModePerm)
+	if err != nil {
+		t.Fatal(err)
+	}
+	err = os.MkdirAll(inputFolderC, os.ModePerm)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	err = os.WriteFile(filepath.Join(inputFolderA, "random.html"), []byte("file a"), 0644)
+	if err != nil {
+		t.Fatal(err)
+	}
+	err = os.WriteFile(filepath.Join(inputFolderB, "random.html"), []byte("file b"), 0644)
+	if err != nil {
+		t.Fatal(err)
+	}
+	err = os.WriteFile(filepath.Join(inputFolderC, "random.html"), []byte("file c"), 0644)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	// - - - - - - - - - //
+	args := []string{"html2markdown", "--input", filepath.Join(".", "input", "**", "*"), "--output", filepath.Join(".", "output") + "/"}
+
+	stdin := &FakeFile{mode: modeTerminal}
+	stdout := &FakeFile{mode: modePipe}
+	stderr := &FakeFile{mode: modePipe}
+
+	Run(stdin, stdout, stderr, args, testRelease)
+
+	if len(stderr.Bytes()) != 0 {
+		t.Fatalf("expected no stderr content but got %q", stderr.String())
+	}
+	if len(stdout.Bytes()) != 0 {
+		t.Fatalf("expected no stdout content")
+	}
+	// - - - - - - - - - //
+
+	expectRepresentation(t, directoryPath, `
+.
+├─input
+│ ├─a
+│ │ ├─random.html "file a"
+│ ├─b
+│ │ ├─random.html "file b"
+│ ├─nested
+│ │ ├─c
+│ │ │ ├─random.html "file c"
+├─output
+│ ├─random.689330a60f.md "file b"
+│ ├─random.f679b6e0c2.md "file c"
+│ ├─random.md "file a"
+	`)
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - //
 
 func TestExecute_FilePattern(t *testing.T) {
@@ -355,7 +446,27 @@ func TestExecute_FilePattern(t *testing.T) {
 ├─output
 │ ├─websites
 │ │ ├─the_cool_website.md "**file content A**"
+			`,
+		},
+		{
+			desc: "output to a specific extension",
+			assembleArgs: func(dir string) []string {
+				input := filepath.Join(dir, "input", "website_a.html")
+				output := filepath.Join(dir, "output", "websites", "the_cool_website.txt")
 
+				return []string{"html2markdown", "--input", input, "--output", output}
+			},
+			expected: `
+.
+├─input
+│ ├─nested
+│ │ ├─website_c.html "<i>file content C</i>"
+│ ├─random.txt "other random file"
+│ ├─website_a.html "<strong>file content A</strong>"
+│ ├─website_b.html "<strong>file content B</strong>"
+├─output
+│ ├─websites
+│ │ ├─the_cool_website.txt "**file content A**"
 			`,
 		},
 		{
@@ -379,6 +490,72 @@ func TestExecute_FilePattern(t *testing.T) {
 
 			`,
 		},
+
+		// - - - - - - - - - - - - relative path - - - - - - - - - - - - //
+		{
+			desc: "relative path: output to a specific file",
+			assembleArgs: func(_ string) []string {
+				input := filepath.Join(".", "input", "website_a.html")
+				output := filepath.Join(".", "output", "websites", "the_cool_website.md")
+
+				return []string{"html2markdown", "--input", input, "--output", output}
+			},
+			expected: `
+.
+├─input
+│ ├─nested
+│ │ ├─website_c.html "<i>file content C</i>"
+│ ├─random.txt "other random file"
+│ ├─website_a.html "<strong>file content A</strong>"
+│ ├─website_b.html "<strong>file content B</strong>"
+├─output
+│ ├─websites
+│ │ ├─the_cool_website.md "**file content A**"
+			`,
+		},
+		{
+			desc: "relative path: direct website html files",
+			assembleArgs: func(_ string) []string {
+				input := filepath.Join(".", "input", "website*.html")
+				output := filepath.Join(".", "output") + string(os.PathSeparator)
+
+				return []string{"html2markdown", "--input", input, "--output", output}
+			},
+			expected: `
+.
+├─input
+│ ├─nested
+│ │ ├─website_c.html "<i>file content C</i>"
+│ ├─random.txt "other random file"
+│ ├─website_a.html "<strong>file content A</strong>"
+│ ├─website_b.html "<strong>file content B</strong>"
+├─output
+│ ├─website_a.md "**file content A**"
+│ ├─website_b.md "**file content B**"
+			`,
+		},
+		{
+			desc: "relative path: output to current directory",
+			assembleArgs: func(_ string) []string {
+				input := filepath.Join(".", "input", "website*.html")
+				output := "." + string(os.PathSeparator)
+
+				return []string{"html2markdown", "--input", input, "--output", output}
+			},
+			expected: `
+.
+├─input
+│ ├─nested
+│ │ ├─website_c.html "<i>file content C</i>"
+│ ├─random.txt "other random file"
+│ ├─website_a.html "<strong>file content A</strong>"
+│ ├─website_b.html "<strong>file content B</strong>"
+├─output
+├─website_a.md "**file content A**"
+├─website_b.md "**file content B**"
+			`,
+		},
+
 		// - - - - - - - - - - - - pattern - - - - - - - - - - - - //
 		{
 			desc: "pattern matches single file",
@@ -522,6 +699,8 @@ func TestExecute_FilePattern(t *testing.T) {
 			directoryPath := newTestDirWithFiles(t)
 			defer os.RemoveAll(directoryPath)
 
+			chdirWithCleanup(t, directoryPath)
+
 			args := tC.assembleArgs(directoryPath)
 			t.Logf("args: %+v\n", args)
 
