@@ -93,6 +93,7 @@ func (cli *CLI) initFlags(progname string) {
 	cli.flags.BoolVar(&cli.config.tableHeaderPromotion, "opt-table-header-promotion", false, "[for --plugin-table] first row should be treated as a header")
 	cli.flags.StringVar(&cli.config.tableSpanCellBehavior, "opt-table-span-cell-behavior", "", `[for --plugin-table] how colspan/rowspan should be rendered: "empty" or "mirror"`)
 	cli.flags.BoolVar(&cli.config.tablePresentationTables, "opt-table-presentation-tables", false, `[for --plugin-table] whether tables with role="presentation" should be converted`)
+	cli.flags.StringVar(&cli.config.tableNewlineBehavior, "opt-table-newline-behavior", "", `[for --plugin-table] how tables containing newlines should be handled: "skip" or "preserve"`)
 }
 
 func (cli *CLI) parseFlags(args []string) error {
@@ -116,6 +117,9 @@ func (cli *CLI) parseFlags(args []string) error {
 	if cli.config.tablePresentationTables && !cli.config.enablePluginTable {
 		return fmt.Errorf("--opt-table-presentation-tables requires --plugin-table to be enabled")
 	}
+	if cli.config.tableNewlineBehavior != "" && !cli.config.enablePluginTable {
+		return fmt.Errorf("--opt-table-newline-behavior requires --plugin-table to be enabled")
+	}
 
 	// TODO: use constant for flag name & use formatFlag
 	//       var keyStrongDelimiter = "opt-strong-delimiter"
